dist_chisquare: Compute Chi-square Distances
Description
A function for computing chi-square distances.Usage
dist_chisquare(x, diag = FALSE, upper = FALSE)
dist_chisq(x, diag = FALSE, upper = FALSE)
Arguments
x
A numeric matrix (containing coordinates).
diag
Logical specifying whether the diagonal of the resulting distance matrix should be printed.
upper
Logical specifying whether the upper triangle of the resulting distance matrix should be printed.